==> v3.51.1.tar.gz: lms-3.51.1/src/libs/database/impl/StarredRelease.cpp <==
/*
 * Copyright (C) 2021 Emeric Poupon
 *
 * This file is part of LMS.
 *
 * LMS is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * LMS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with LMS.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "database/StarredRelease.hpp"

#include <Wt/Dbo/WtSqlTraits.h>

#include "database/Release.hpp"
#include "database/Session.hpp"
#include "database/User.hpp"
#include "IdTypeTraits.hpp"
#include "Utils.hpp"

namespace lms::db
{
    StarredRelease::StarredRelease(ObjectPtr<Release> release, ObjectPtr<User> user, FeedbackBackend backend)
        : _backend{ backend }
        , _release{ getDboPtr(release) }
        , _user{ getDboPtr(user) }
    {
    }

    StarredRelease::pointer StarredRelease::create(Session& session, ObjectPtr<Release> release, ObjectPtr<User> user, FeedbackBackend backend)
    {
        return session.getDboSession().add(std::unique_ptr<StarredRelease>{new StarredRelease{ release, user, backend }});
    }

    std::size_t StarredRelease::getCount(Session& session)
    {
        session.checkReadTransaction();
        return session.getDboSession().query<int>("SELECT COUNT(*) FROM starred_release");
    }

    StarredRelease::pointer StarredRelease::find(Session& session, StarredReleaseId id)
    {
        session.checkReadTransaction();
        return session.getDboSession().find<StarredRelease>().where("id = ?").bind(id).resultValue();
    }

    StarredRelease::pointer StarredRelease::find(Session& session, ReleaseId releaseId, UserId userId)
    {
        session.checkReadTransaction();
        return session.getDboSession().query<Wt::Dbo::ptr<StarredRelease>>("SELECT s_r from starred_release s_r")
            .join("user u ON u.id = s_r.user_id")
            .where("s_r.release_id = ?").bind(releaseId)
            .where("s_r.user_id = ?").bind(userId)
            .where("s_r.backend = u.feedback_backend")
            .resultValue();
    }

    StarredRelease::pointer StarredRelease::find(Session& session, ReleaseId releaseId, UserId userId, FeedbackBackend backend)
    {
        session.checkReadTransaction();
        return session.getDboSession().find<StarredRelease>()
            .where("release_id = ?").bind(releaseId)
            .where("user_id = ?").bind(userId)
            .where("backend = ?").bind(backend)
            .resultValue();
    }

    void StarredRelease::setDateTime(const Wt::WDateTime& dateTime)
    {
        _dateTime = utils::normalizeDateTime(dateTime);
    }
}

==> v3.58.0.tar.gz: lms-3.58.0/src/libs/database/impl/StarredRelease.cpp <==
/*
 * Copyright (C) 2021 Emeric Poupon
 *
 * This file is part of LMS.
 *
 * LMS is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * LMS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with LMS.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "database/StarredRelease.hpp"

#include <Wt/Dbo/WtSqlTraits.h>

#include "database/Release.hpp"
#include "database/Session.hpp"
#include "database/User.hpp"

#include "IdTypeTraits.hpp"
#include "Utils.hpp"

namespace lms::db
{
    StarredRelease::StarredRelease(ObjectPtr<Release> release, ObjectPtr<User> user, FeedbackBackend backend)
        : _backend{ backend }
        , _release{ getDboPtr(release) }
        , _user{ getDboPtr(user) }
    {
    }

    StarredRelease::pointer StarredRelease::create(Session& session, ObjectPtr<Release> release, ObjectPtr<User> user, FeedbackBackend backend)
    {
        return session.getDboSession()->add(std::unique_ptr<StarredRelease>{ new StarredRelease{ release, user, backend } });
    }

    std::size_t StarredRelease::getCount(Session& session)
    {
        session.checkReadTransaction();
        return session.getDboSession()->query<int>("SELECT COUNT(*) FROM starred_release");
    }

    StarredRelease::pointer StarredRelease::find(Session& session, StarredReleaseId id)
    {
        session.checkReadTransaction();
        return utils::fetchQuerySingleResult(session.getDboSession()->find<StarredRelease>().where("id = ?").bind(id));
    }

    StarredRelease::pointer StarredRelease::find(Session& session, ReleaseId releaseId, UserId userId)
    {
        session.checkReadTransaction();
        return utils::fetchQuerySingleResult(session.getDboSession()->query<Wt::Dbo::ptr<StarredRelease>>("SELECT s_r from starred_release s_r").join("user u ON u.id = s_r.user_id").where("s_r.release_id = ?").bind(releaseId).where("s_r.user_id = ?").bind(userId).where("s_r.backend = u.feedback_backend"));
    }

    StarredRelease::pointer StarredRelease::find(Session& session, ReleaseId releaseId, UserId userId, FeedbackBackend backend)
    {
        session.checkReadTransaction();
        return utils::fetchQuerySingleResult(session.getDboSession()->find<StarredRelease>().where("release_id = ?").bind(releaseId).where("user_id = ?").bind(userId).where("backend = ?").bind(backend));
    }

    void StarredRelease::setDateTime(const Wt::WDateTime& dateTime)
    {
        _dateTime = utils::normalizeDateTime(dateTime);
    }
} // namespace lms::db
